@@ -56,7 +56,13 @@ Fl_Menu_Item touch_menu[] = {
  {_("Power meter scale"), 0, (Fl_Callback*)cb_mnu_power_meter_scale, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Tooltips"), 0,  (Fl_Callback*)cb_mnuTooltips, 0, 130, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Voltmeter"), 0, (Fl_Callback*)cb_mnuVoltmeter, 0, 130, FL_NORMAL_LABEL, 0, 14, 0},
- {_("User Interface"), 0,  (Fl_Callback*)cb_mnuColorConfig, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Configuration"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("User Interface"), 0,  (Fl_Callback*)cb_mnuUIConfig, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Controls Colors"), 0,  (Fl_Callback*)cb_mnuColorConfig, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Save prefs"), 0, (Fl_Callback*)cb_save_prefs, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Save As prefs"), 0, (Fl_Callback*)cb_save_as_prefs, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Load prefs"), 0, (Fl_Callback*)cb_load_prefs, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {0,0,0,0,0,0,0,0,0},
  {0,0,0,0,0,0,0,0,0},
  {0,0,0,0,0,0,0,0,0},
  {_("&Memory"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
@@ -599,7 +605,7 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 			sldrSQUELCH->labelcolor(FL_FOREGROUND_COLOR);
 			sldrSQUELCH->maximum(100);
 			sldrSQUELCH->step(1);
-			sldrSQUELCH->value(15);
+			sldrSQUELCH->value(progStatus.squelch);
 			sldrSQUELCH->textsize(14);
 			sldrSQUELCH->callback((Fl_Callback*)cb_sldrSQUELCH);
 			sldrSQUELCH->align(Fl_Align(FL_ALIGN_LEFT));
@@ -1237,7 +1243,7 @@ CTRL  click: FreqB -> FreqA\
 				btnSpot->value(progStatus.cw_spot);
 
 				spnr_cw_spot_tone = new Hspinner(
-					btnSpot->x() + btnSpot->w() + 75, by,
+					btnSpot->x() + btnSpot->w() + 50, by,
 					5*bh, bh, _("Spot tone"));
 				spnr_cw_spot_tone->tooltip(_("Spot tone freq"));
 				spnr_cw_spot_tone->type(FL_INT_INPUT);
@@ -1250,7 +1256,7 @@ CTRL  click: FreqB -> FreqA\
 				spnr_cw_spot_tone->align(FL_ALIGN_CENTER | FL_ALIGN_BOTTOM);
 
 				spnr_cw_weight = new Hspinner(
-					spnr_cw_spot_tone->x() + spnr_cw_spot_tone->w() + 75, by,
+					spnr_cw_spot_tone->x() + spnr_cw_spot_tone->w() +50, by,
 					5*bh, bh, _("Weight"));
 				spnr_cw_weight->type(FL_INT_INPUT);
 				spnr_cw_weight->minimum(2.5);
@@ -1262,7 +1268,7 @@ CTRL  click: FreqB -> FreqA\
 				spnr_cw_weight->tooltip(_("CW weight"));
 
 				spnr_cw_wpm = new Hspinner(
-					spnr_cw_weight->x() + spnr_cw_weight->w() + 75, by,
+					spnr_cw_weight->x() + spnr_cw_weight->w() +50, by,
 					5*bh, bh, _("wpm"));
 				spnr_cw_wpm->type(FL_INT_INPUT);
 				spnr_cw_wpm->minimum(5);
@@ -1273,8 +1279,22 @@ CTRL  click: FreqB -> FreqA\
 				spnr_cw_wpm->align(FL_ALIGN_CENTER | FL_ALIGN_BOTTOM);
 				spnr_cw_wpm->tooltip(_("CW words per minute"));
 
+				spnr_cw_vol= new Hspinner(
+					spnr_cw_weight->w() + spnr_cw_weight->x() + 50, by,
+					5*bh, bh, _("CW vol"));
+				spnr_cw_vol->type(1);
+				spnr_cw_vol->minimum(0);
+				spnr_cw_vol->maximum(100);
+				spnr_cw_vol->step(1);
+				spnr_cw_vol->value(50);
+				spnr_cw_vol->callback((Fl_Callback*)cb_spnr_cw_vol);
+				spnr_cw_vol->value(progStatus.cw_vol);
+				spnr_cw_vol->labelsize(12);
+				spnr_cw_vol->align(FL_ALIGN_BOTTOM | FL_ALIGN_CENTER);
+				spnr_cw_vol->tooltip(_("CW volume"));
+
 				btn_enable_keyer = new Fl_Check_Button(
-					spnr_cw_wpm->x() + spnr_cw_wpm->w() + 10, by,
+					spnr_cw_vol->x() + spnr_cw_vol->w() + 10, by,
 					5*bh, bh, _("Keyer"));
 				btn_enable_keyer->tooltip(_("Enable internal keyer"));
 				btn_enable_keyer->down_box(FL_DOWN_BOX);
