@@ -51,7 +51,13 @@ Fl_Menu_Item menu_wide_menu[] = {
  {_("Embed tabs"), 0, (Fl_Callback*)cb_mnu_embed_tabs, 0, 130, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Tooltips"), 0,  (Fl_Callback*)cb_mnuTooltips, 0, 130, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Voltmeter"), 0, (Fl_Callback*)cb_mnuVoltmeter, 0, 130, FL_NORMAL_LABEL, 0, 14, 0},
- {_("User Interface"), 0,  (Fl_Callback*)cb_mnuColorConfig, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Configuration"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("User Interface"), 0,  (Fl_Callback*)cb_mnuUIConfig, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Controls Colors"), 0,  (Fl_Callback*)cb_mnuColorConfig, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Save prefs"), 0, (Fl_Callback*)cb_save_prefs, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Save As prefs"), 0, (Fl_Callback*)cb_save_as_prefs, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Load prefs"), 0, (Fl_Callback*)cb_load_prefs, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {0,0,0,0,0,0,0,0,0},
  {0,0,0,0,0,0,0,0,0},
  {0,0,0,0,0,0,0,0,0},
  {_("&Memory"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
@@ -613,7 +619,7 @@ CTRL  click: FreqB -> FreqA\
 				sldrSQUELCH->labelcolor(FL_FOREGROUND_COLOR);
 				sldrSQUELCH->maximum(100);
 				sldrSQUELCH->step(1);
-				sldrSQUELCH->value(15);
+				sldrSQUELCH->value(progStatus.squelch);
 				sldrSQUELCH->textsize(12);
 				sldrSQUELCH->callback((Fl_Callback*)cb_sldrSQUELCH);
 				sldrSQUELCH->align(Fl_Align(FL_ALIGN_LEFT));
