@@ -135,6 +135,7 @@ public:
 	int  get_power_out(void);
 	int  get_swr(void);
 	int  get_alc(void);
+	double get_idd(void);
 
 	double get_voltmeter(void);
 
@@ -154,9 +155,6 @@ public:
 	int  get_attenuator();
 	int  next_attenuator();
 
-	const char * PRE_label();
-	const char * ATT_label();
-
 	void set_noise(bool val);
 	int  get_noise();
 	void set_nb_level(int val);
