@@ -156,9 +156,6 @@ public:
 	int get_preamp();
 	int next_preamp();
 
-	const char * PRE_label();
-	const char * ATT_label();
-
 	void set_pbt_inner(int val);
 	void set_pbt_outer(int val);
 
@@ -179,6 +176,9 @@ public:
 
 	void set_xcvr_auto_on();
 	void set_xcvr_auto_off();
+
+	void sync_date(char *dt);
+	void sync_clock(char *tm);
 };
 
 #endif
