@@ -88,9 +88,6 @@ public:
 	void set_preamp(int val);
 	int  get_preamp();
 
-	const char * ATT_label();
-	const char * PRE_label();
-
 	void set_if_shift(int val);
 	bool get_if_shift(int &val);
 	void get_if_min_max_step(int &min, int &max, int &step);
@@ -125,11 +122,11 @@ public:
 	void set_break_in();
 	int  get_break_in();
 
-	void get_cw_weight();
-	void get_cw_wpm();
+	int  get_cw_weight();
+	int  get_cw_wpm();
 	void get_qsk();
 	void get_qsk_delay();
-	void get_cw_spot_tone();
+	int  get_cw_spot_tone();
 	void get_vox_gain();
 	void get_vox_hang();
 
