@@ -97,9 +97,6 @@ public:
 	void set_preamp(int val);
 	int  get_preamp();
 
-	const char * ATT_label();
-	const char * PRE_label();
-
 	void set_if_shift(int val);
 	bool get_if_shift(int &val);
 	void get_if_min_max_step(int &min, int &max, int &step);
@@ -149,6 +146,11 @@ public:
 	void set_noise_reduction(int val);
 	int  get_noise_reduction();
 
+	void set_squelch(int val);
+	int  get_squelch();
+	void get_squelch_min_max_step(int &min, int &max, int &step) {
+		min = 0; max = 100; step = 5; }
+
 	void set_xcvr_auto_on();
 	void set_xcvr_auto_off();
 
