@@ -41,37 +41,38 @@ const char IC705name_[] = "IC-705";
 // these are only defined in this file
 // undef'd at end of file
 #define NUM_FILTERS 3
-#define NUM_MODES  13
+#define NUM_MODES  14
 
-static int mode_filterA[NUM_MODES] = {1,1,1,1,1,1,1,1,1,1,1,1};
-static int mode_filterB[NUM_MODES] = {1,1,1,1,1,1,1,1,1,1,1,1};
+static int mode_filterA[NUM_MODES] = {1,1,1,1,1,1,1,1,1,1,1,1,1,1};
+static int mode_filterB[NUM_MODES] = {1,1,1,1,1,1,1,1,1,1,1,1,1,1};
 
-static int mode_bwA[NUM_MODES] = {-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1};
-static int mode_bwB[NUM_MODES] = {-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1};
+static int mode_bwA[NUM_MODES] = {-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1};
+static int mode_bwB[NUM_MODES] = {-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1};
 
 static const char *szfilter[NUM_FILTERS] = {"1", "2", "3"};
 
 enum {
 LSB705, USB705, AM705, FM705,
 CW705, CWR705, RTTY705, RTTYR705,
-LSBD705, USBD705, AMD705, FMD705, DV705
+LSBD705, USBD705, AMD705, FMD705, DV705,
+WFM705
 };
 
 static std::vector<std::string>IC705modes_;
 static const char *vIC705modes_[] =
 {	"LSB", "USB", "AM", "FM",
 	"CW", "CW-R", "RTTY", "RTTY-R",
-	"LSB-D", "USB-D", "AM-D", "FM-D", "DV"};
+	"LSB-D", "USB-D", "AM-D", "FM-D", "DV", "WFM"};
 
 char IC705_mode_type[] = {
 	'L', 'U', 'U', 'U',
 	'L', 'U', 'L', 'U',
-	'L', 'U', 'U', 'U', 'U' };
+	'L', 'U', 'U', 'U', 'U', 'U' };
 
 const char IC705_mode_nbr[] = {
 	0x00, 0x01, 0x02, 0x05,
 	0x03, 0x07, 0x04, 0x08,
-	0x00, 0x01, 0x02, 0x05, 0x17 };
+	0x00, 0x01, 0x02, 0x05, 0x17, 0x06 };
 
 static std::vector<std::string>IC705_ssb_bws;
 static const char *vIC705_ssb_bws[] =
@@ -122,6 +123,14 @@ static const char *vIC705_fm_bws[] =
 { "FIXED" };
 static int IC705_bw_vals_FM[] = { 1, WVALS_LIMIT};
 
+//----------------------------------------------------------------------
+static std::vector<std::string>IC705_att_labels;
+static const char *vIC705_att_labels[] = { "ATT", "20 dB" };
+
+static std::vector<std::string>IC705_pre_labels;
+static const char *vIC705_pre_labels[] = { "PRE", "Pre 1", "Pre 2"};
+//----------------------------------------------------------------------
+
 static GUI IC705_widgets[]= {
 	{ (Fl_Widget *)btnVol,        2, 125,  50 },	//0
 	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 },	//1
@@ -153,6 +162,12 @@ void RIG_IC705::initialize()
 	bandwidths_ = IC705_ssb_bws;
 	bw_vals_ = IC705_bw_vals_SSB;
 
+	VECTOR (IC705_att_labels, vIC705_att_labels);
+	VECTOR (IC705_pre_labels, vIC705_pre_labels);
+
+	att_labels_ = IC705_att_labels;
+	pre_labels_ = IC705_pre_labels;
+
 	_mode_type = IC705_mode_type;
 
 	IC705_widgets[0].W = btnVol;
@@ -240,6 +255,7 @@ RIG_IC705::RIG_IC705() {
 	has_power_out = true;
 	has_swr_control = true;
 	has_alc_control = true;
+	has_idd_control = true;
 	has_sql_control = true;
 	has_agc_control = true;
 
@@ -496,6 +512,7 @@ void RIG_IC705::set_vfoB (unsigned long long freq)
 //                |                03 - CW
 //                |                04 - RTTY
 //                |                05 - FM
+//                |                06 - WFM
 //                |                07 - CW-R
 //                |                08 - RTTY-R
 //                |                17 - DV
@@ -830,7 +847,10 @@ int RIG_IC705::get_split()
 
 int RIG_IC705::get_bwA()
 {
-	if (A.imode == 3 || A.imode == 11) return 0; // FM, FM-D
+	// FM, FM-D, WFM
+	if (A.imode == FM705 || A.imode == FMD705 ||
+	    A.imode == WFM705)
+		return 0;
 
 	int current_vfo = inuse;
 	if (current_vfo == onB) selectA();
@@ -861,7 +881,10 @@ int RIG_IC705::get_bwA()
 void RIG_IC705::set_bwA(int val)
 {
 
-	if (A.imode == 3 || A.imode == 11) return; // FM, FM-D
+	// FM, FM-D, WFM
+	if (A.imode == FM705 || A.imode == FMD705 ||
+	    A.imode == WFM705)
+		return;
 
 	A.iBW = val;
 
@@ -882,7 +905,10 @@ void RIG_IC705::set_bwA(int val)
 
 int RIG_IC705::get_bwB()
 {
-	if (B.imode == 3 || B.imode == 11) return 0; // FM, FM-D
+	// FM, FM-D, WFM
+	if (B.imode == FM705 || B.imode == FMD705 ||
+	    B.imode == WFM705)
+		return 0;
 
 	int current_vfo = inuse;
 	if (current_vfo == onA) selectB();
@@ -912,7 +938,11 @@ int RIG_IC705::get_bwB()
 
 void RIG_IC705::set_bwB(int val)
 {
-	if (B.imode == 3 || B.imode == 11) return; // FM, FM-D
+	// FM, FM-D, WFM
+	if (B.imode == FM705 || B.imode == FMD705 ||
+	    B.imode == WFM705)
+		return;
+
 	B.iBW = val;
 
 	int current_vfo = inuse;
@@ -932,34 +962,44 @@ void RIG_IC705::set_bwB(int val)
 
 // LSB  USB  AM   FM   CW  CW-R  RTTY  RTTY-R  LSB-D  USB-D  AM-D  FM-D
 //  0    1    2    3   4     5    6     7      8      9       10    11
+//  DV  WFM
+//  12   13
 
 int RIG_IC705::adjust_bandwidth(int m)
 {
 	int bw = 0;
 	switch (m) {
-		case 2: case 10: // AM, AM-D
+		case AM705: case AMD705:
+			// AM, AM-D
 			bandwidths_ = IC705_am_bws;
 			bw_vals_ = IC705_bw_vals_AM;
 			bw = 19;
 			break;
-		case 3: case 11: case 12: // FM, FM-D, DV
+		case FM705: case FMD705:
+		case DV705: case WFM705:
+			// FM, FM-D, DV, WFM
 			bandwidths_ = IC705_fm_bws;
 			bw_vals_ = IC705_bw_vals_FM;
 			bw = 0;
 			break;
-		case 6: case 7: // RTTY, RTTY-R
+		case RTTY705: case RTTYR705:
+			// RTTY, RTTY-R
 			bandwidths_ = IC705_rtty_bws;
 			bw_vals_ = IC705_bw_vals_RTTY;
 			bw = 12;
 			break;
-		case 4: case 5: // CW, CW -R
+		case CW705: case CWR705:
+			// CW, CW -R
 			bandwidths_ = IC705_ssb_bws;
 			bw_vals_ = IC705_bw_vals_SSB;
 			bw = 12;
 			break;
-		case 0: case 1: // LSB, USB
-		case 8: case 9: // LSB-D, USB-D
+		case LSB705: case USB705:
+		case LSBD705: case USBD705:
 		default:
+			// CW, CW -R
+			// LSB, USB
+			// LSB-D, USB-D
 			bandwidths_ = IC705_ssb_bws;
 			bw_vals_ = IC705_bw_vals_SSB;
 			bw = 34;
@@ -1385,9 +1425,7 @@ double RIG_IC705::get_voltmeter()
 	return -1;
 }
 
-struct pwrpair {int mtr; float pwr;};
-
-static pwrpair pwrtbl[] = {
+static meterpair pwrtbl[] = {
 	{0,   0.0},
 	{26,  0.5},
 	{52,  1.0},
@@ -1422,13 +1460,13 @@ int RIG_IC705::get_power_out(void)
 		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			size_t i = 0;
-			for (i = 0; i < sizeof(pwrtbl) / sizeof(pwrpair) - 1; i++)
+			for (i = 0; i < sizeof(pwrtbl) / sizeof(*pwrtbl) - 1; i++)
 				if (mtr >= pwrtbl[i].mtr && mtr < pwrtbl[i+1].mtr)
 					break;
 			if (mtr < 0) mtr = 0;
 			if (mtr > 255) mtr = 255;
-			mtr = (int)ceil(pwrtbl[i].pwr +
-				(pwrtbl[i+1].pwr - pwrtbl[i].pwr)*(mtr - pwrtbl[i].mtr)/(pwrtbl[i+1].mtr - pwrtbl[i].mtr));
+			mtr = (int)ceil(pwrtbl[i].val +
+				(pwrtbl[i+1].val - pwrtbl[i].val)*(mtr - pwrtbl[i].mtr)/(pwrtbl[i+1].mtr - pwrtbl[i].mtr));
 
 			if (mtr > 100) mtr = 100;
 		}
@@ -1436,13 +1474,10 @@ int RIG_IC705::get_power_out(void)
 	return mtr;
 }
 
-struct swrpair {int mtr; float swr;};
-
 // Table entries below correspond to SWR readings of 1.1, 1.5, 2.0, 2.5, 3.0 and infinity.
 // Values are also tweaked to fit the display of the SWR meter.
 
-
-static swrpair swrtbl[] = {
+static meterpair swrtbl[] = {
 	{0, 0.0},
 	{48, 10.5},
 	{80, 23.0},
@@ -1466,13 +1501,13 @@ int RIG_IC705::get_swr(void)
 		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			size_t i = 0;
-			for (i = 0; i < sizeof(swrtbl) / sizeof(swrpair) - 1; i++)
+			for (i = 0; i < sizeof(swrtbl) / sizeof(*swrtbl) - 1; i++)
 				if (mtr >= swrtbl[i].mtr && mtr < swrtbl[i+1].mtr)
 					break;
 			if (mtr < 0) mtr = 0;
 			if (mtr > 255) mtr = 255;
-			mtr = (int)ceil(swrtbl[i].swr +
-				(swrtbl[i+1].swr - swrtbl[i].swr)*(mtr - swrtbl[i].mtr)/(swrtbl[i+1].mtr - swrtbl[i].mtr));
+			mtr = (int)ceil(swrtbl[i].val +
+				(swrtbl[i+1].val - swrtbl[i].val)*(mtr - swrtbl[i].mtr)/(swrtbl[i+1].mtr - swrtbl[i].mtr));
 
 			if (mtr > 100) mtr = 100;
 		}
@@ -1500,6 +1535,31 @@ int RIG_IC705::get_alc(void)
 	return mtr;
 }
 
+double RIG_IC705::get_idd(void)
+{
+	get_trace(1, "get_idd()");
+	std::string cstr = "\x15\x16";
+	std::string resp = pre_fm;
+	resp.append(cstr);
+	cmd = pre_to;
+	cmd.append(cstr);
+	cmd.append( post );
+	double mtr= 0;
+
+	int ret = waitFOR(9, "get idd");
+	igett("");
+
+	if (ret) {
+		size_t p = replystr.rfind(resp);
+		if (p != std::string::npos) {
+			mtr = fm_bcd(replystr.substr(p+6), 3);
+			mtr = 4.0 * mtr / 241.0;
+			if (mtr > 4) mtr = 4;
+		}
+	}
+	return mtr;
+}
+
 void RIG_IC705::set_rf_gain(int val)
 {
 	cmd = pre_to;
@@ -1532,9 +1592,9 @@ void RIG_IC705::get_rf_min_max_step(double &min, double &max, double &step)
 
 int RIG_IC705::next_preamp()
 {
-	if (atten_level == 1)
-		return preamp_level;
-	switch (preamp_level) {
+	if (atten_state == 1)
+		return preamp_state;
+	switch (preamp_state) {
 		case 0: return 1;
 		case 1: return 2;
 		case 2: return 0;
@@ -1548,12 +1608,12 @@ void RIG_IC705::set_preamp(int val)
 	cmd += '\x16';
 	cmd += '\x02';
 
-	preamp_level = val;
+	preamp_state = val;
 
-	cmd += (unsigned char)preamp_level;
+	cmd += (unsigned char)preamp_state;
 	cmd.append( post );
-	waitFB(	(preamp_level == 0) ? "set Preamp OFF" :
-			(preamp_level == 1) ? "set Preamp Level 1" :
+	waitFB(	(preamp_state == 0) ? "set Preamp OFF" :
+			(preamp_state == 1) ? "set Preamp Level 1" :
 			"set Preamp Level 2");
 }
 
@@ -1568,30 +1628,30 @@ int RIG_IC705::get_preamp()
 	if (waitFOR(8, "get Preamp Level")) {
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
-			preamp_level = replystr[p+6];
+			preamp_state = replystr[p+6];
 		}
 	}
-	return preamp_level;
+	return preamp_state;
 }
 
 void RIG_IC705::set_attenuator(int val)
 {
 	if (val) {
-		atten_level = 1;
+		atten_state = 1;
 	} else {
-		atten_level = 0;
+		atten_state = 0;
 	}
 
 	cmd = pre_to;
 	cmd += '\x11';
-	cmd += atten_level ? '\x20' : '\x00';
+	cmd += atten_state ? '\x20' : '\x00';
 	cmd.append( post );
 	waitFB("set att");
 }
 
 int RIG_IC705::next_attenuator()
 {
-	if (atten_level) return 0;
+	if (atten_state) return 0;
 	return 1;
 }
 
@@ -1606,10 +1666,10 @@ int RIG_IC705::get_attenuator()
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
 			if (replystr[p+5] == 0x20) {
-				atten_level = 1;
+				atten_state = 1;
 				return 1;
 			} else {
-				atten_level = 0;
+				atten_state = 0;
 				return 0;
 			}
 		}
@@ -1617,25 +1677,6 @@ int RIG_IC705::get_attenuator()
 	return 0;
 }
 
-const char *RIG_IC705::PRE_label()
-{
-	switch (preamp_level) {
-		case 0: default:
-			return "PRE"; break;
-		case 1:
-			return "Pre 1"; break;
-		case 2:
-			return "Pre 2"; break;
-	}
-	return "PRE";
-}
-
-const char *RIG_IC705::ATT_label()
-{
-	if (atten_level == 1) return "20 dB";
-	return "ATT";
-}
-
 void RIG_IC705::set_noise(bool val)
 {
 	cmd = pre_to;
@@ -1789,12 +1830,14 @@ int  RIG_IC705::get_squelch()
 
 void RIG_IC705::set_auto_notch(int val)
 {
+	progStatus.auto_notch = an_level = val;
 	cmd = pre_to;
 	cmd += '\x16';
 	cmd += '\x41';
 	cmd += (unsigned char)val;
 	cmd.append( post );
 	waitFB("set AN");
+	auto_notch_label(an_label(), an_level ? true : false);
 }
 
 int RIG_IC705::get_auto_notch()
@@ -1808,13 +1851,8 @@ int RIG_IC705::get_auto_notch()
 	if (waitFOR(8, "get AN")) {
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
-			if (replystr[p+6] == 0x01) {
-				auto_notch_label("AN", true);
-				return true;
-			} else {
-				auto_notch_label("AN", false);
-				return false;
-			}
+			progStatus.auto_notch = an_level = replystr[p+6];
+			auto_notch_label(an_label(), an_level ? true : false);
 		}
 	}
 	return progStatus.auto_notch;
@@ -1938,7 +1976,7 @@ void RIG_IC705::get_notch_min_max_step(int &min, int &max, int &step)
 			break;
 	}
 }
-static int agcval = 3;
+
 int  RIG_IC705::get_agc()
 {
 	cmd = pre_to;
