@@ -96,6 +96,10 @@ static const char *vvarwidths[] = {
 "  500", "  200" };
 
 //------------------------------------------------------------------------------
+static std::vector<std::string>XCVR_nr_labels;
+static const char *vXCVR_nr_labels[] = { "NR", "NR 1", "NR 2" };
+//------------------------------------------------------------------------------
+
 static GUI rig_widgets[]= {
 	{ (Fl_Widget *)btnVol,        2, 125,  50 }, // 0
 	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 }, // 1
@@ -130,6 +134,9 @@ void RIG_PowerSDR::initialize()
 	VECTOR (PowerSDR_CAT_CW, vPowerSDR_CAT_CW);
 	VECTOR (varwidths, vvarwidths);
 
+	VECTOR (XCVR_nr_labels, vXCVR_nr_labels);
+	nr_labels_ = XCVR_nr_labels;
+
 	modes_ = PowerSDRmodes_;
 	bandwidths_ = PowerSDR_empty;
 
@@ -242,9 +249,9 @@ RIG_PowerSDR::RIG_PowerSDR() {
 	precision = 1;
 	ndigits = 9;
 
-	att_level = 0;
+	atten_state = 0;
 //	preamp_level = 0;
-	_noise_reduction_level = 0;
+	nr_state = 0;
 	_nrval1 = 2;
 	_nrval2 = 4;
 
@@ -341,12 +348,9 @@ double RIG_PowerSDR::get_power_control()
 	return pctrl;
 }
 
-struct meterpair {float mtr; float val;};
-
 // Table entries below correspond to SWR readings of 1.1, 1.5, 2.0, 2.5, 3.0 and infinity.
 // Values are also tweaked to fit the display of the SWR meter.
 
-
 static meterpair swr_tbl[] = {
     {1.0, 0},
     {1.5, 12.0 },
@@ -958,17 +962,17 @@ void RIG_PowerSDR::set_noise_reduction(int val)
 	if (val == -1) {
 		return;
 	}
-	_noise_reduction_level = val;
-	if (_noise_reduction_level == 0) {
-		nr_label("ZZNR0", 0);
-	} else if (_noise_reduction_level == 1) {
-		nr_label("ZZNR1", 1);
+	nr_state = val;
+	if (nr_state == 0) {
+		noise_reduction_label("NR", 0);
+	} else if (nr_state == 1) {
+		noise_reduction_label("NR 1", 1);
 	} else {
-		nr_label("???", 2);
+		noise_reduction_label("NR ??", 2);
 		return;
 	}
 	cmd.assign("ZZNR");
-	cmd += '0' + _noise_reduction_level;
+	cmd += '0' + nr_state;
 	cmd += ';';
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET noise reduction", cmd, "");
@@ -984,24 +988,22 @@ int  RIG_PowerSDR::get_noise_reduction()
 	gett("");
 	if (ret == 6) {
 		size_t p = replystr.rfind(rsp);
-		if (p == std::string::npos) return _noise_reduction_level;
-		_noise_reduction_level = replystr[p+4] - '0';
+		if (p == std::string::npos) return nr_state;
+		nr_state = replystr[p+4] - '0';
 	}
 
-	if (_noise_reduction_level == 1) {
-		nr_label("NR", 1);
-	} else if (_noise_reduction_level == 2) {
-		nr_label("NR2", 2);
+	if (nr_state == 1) {
+		noise_reduction_label("NR 1", 1);
 	} else {
-		nr_label("NR", 0);
+		noise_reduction_label("NR", 0);
 	}
-	return _noise_reduction_level;
+	return nr_state;
 }
 
 void RIG_PowerSDR::set_noise_reduction_val(int val)
 {
-	if (_noise_reduction_level == 0) return;
-	if (_noise_reduction_level == 1) _nrval1 = val;
+	if (nr_state == 0) return;
+	if (nr_state == 1) _nrval1 = val;
 	else _nrval2 = val;
 
 	cmd.assign("NR").append(to_decimal(val, 2)).append(";");
@@ -1013,7 +1015,7 @@ void RIG_PowerSDR::set_noise_reduction_val(int val)
 int  RIG_PowerSDR::get_noise_reduction_val()
 {
 	int nrval = 0;
-	if (_noise_reduction_level == 0) return 0;
+	if (nr_state == 0) return 0;
 	int val = progStatus.noise_reduction_val;
 	cmd = rsp = "ZZNR";
 	cmd.append(";");
@@ -1023,12 +1025,12 @@ int  RIG_PowerSDR::get_noise_reduction_val()
 	if (ret == 5) {
 		size_t p = replystr.rfind(rsp);
 		if (p == std::string::npos) {
-			nrval = (_noise_reduction_level == 1 ? _nrval1 : _nrval2);
+			nrval = (nr_state == 1 ? _nrval1 : _nrval2);
 			return nrval;
 		}
 		val = atoi(&replystr[p+2]);
 	}
-	if (_noise_reduction_level == 1) _nrval1 = val;
+	if (nr_state == 1) _nrval1 = val;
 	else _nrval2 = val;
 
 	return val;
@@ -1221,8 +1223,6 @@ void RIG_PowerSDR::get_squelch_min_max_step(int &min, int &max, int &step)
 	step = 4;
 }
 
-static int agcval = 1;
-
 int  RIG_PowerSDR::get_agc()
 {
 	cmd = "GT;";
