@@ -594,100 +594,3 @@ int RIG_XI5105::get_bwB()
 	return filter_nbr - 1;
 }
 
-/*
-void RIG_XI5105::set_auto_notch(int val)
-{
-	cmd = pre_to;
-	cmd += '\x16';
-	cmd += '\x41';
-	cmd += (unsigned char)val;
-	cmd.append( post );
-	waitFB("set AN");
-}
-
-int RIG_XI5105::get_auto_notch()
-{
-	cmd = pre_to;
-	cmd += '\x16';
-	cmd += '\x41';
-	cmd.append( post );
-	std::string resp = pre_fm;
-	resp += '\x16';
-	resp += '\x41';
-	if (waitFOR(8, "get AN")) {
-		size_t p = replystr.rfind(resp);
-		if (p != std::string::npos) {
-			if (replystr[6] == 0x01) {
-				auto_notch_label("AN", true);
-				return 1;
-			} else {
-				auto_notch_label("AN", false);
-				return 0;
-			}
-		}
-	}
-	return 0;
-}
-
-void RIG_XI5105::set_compression(int on, int val)
-{
-	if (on) {
-		cmd = pre_to;
-		cmd.append("\x16\x44");
-		cmd += '\x01';
-		cmd.append(post);
-		waitFB("set compON");
-	} else {
-		cmd = pre_to;
-		cmd.append("\x16\x44");
-		cmd += '\x00';
-		cmd.append(post);
-		waitFB("set compOFF");
-	}
-}
-
-void RIG_XI5105::set_vox_onoff()
-{
-	if (progStatus.vox_onoff) {
-		cmd = pre_to;
-		cmd.append("\x16\x46");
-		cmd += '\x01';
-		cmd.append(post);
-		waitFB("set voxON");
-	} else {
-		cmd = pre_to;
-		cmd.append("\x16\x46");
-		cmd += '\x00';
-		cmd.append(post);
-		waitFB("set voxOFF");
-	}
-}
-
-void RIG_XI5105::set_split(bool val)
-{
-	split = val;
-	cmd = pre_to;
-	cmd += 0x0F;
-	cmd += val ? 0x01 : 0x00;
-	cmd.append(post);
-	waitFB(val ? "set split ON" : "set split OFF");
-}
-
-int RIG_XI5105::get_split()
-{
-	int read_split = 0;
-	cmd.assign(pre_to);
-	cmd.append("\x0F");
-	cmd.append( post );
-	if (waitFOR(7, "get split")) {
-		std::string resp = pre_fm;
-		resp.append("\x0F");
-		size_t p = replystr.find(resp);
-		if (p != std::string::npos)
-			read_split = replystr[p+5];
-		if (read_split != 0xFA) // fail byte
-			split = read_split;
-	}
-	return split;
-}
-*/
