@@ -76,15 +76,31 @@ static const char *vFT2000_US_60m[] = {"", "126", "127", "128", "130"};
 
 static std::vector<std::string>& Channels_60m = FT2000_US_60m;
 
+//----------------------------------------------------------------------
+static std::vector<std::string>FT2000_att_labels;
+static const char *vFT2000_att_labels[] = { "ATT", "6 dB", "12 dB", "18 dB"};
+
+static std::vector<std::string>FT2000_pre_labels;
+static const char *vFT2000_pre_labels[] = { "PRE", "Amp 1", "Amp 2"};
+//----------------------------------------------------------------------
+
 static GUI rig_widgets[]= {
-	{ (Fl_Widget *)btnVol,        2, 125,  50 },
-	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 },
-	{ (Fl_Widget *)btnIFsh,     214, 105,  50 },
-	{ (Fl_Widget *)sldrIFSHIFT, 266, 105, 156 },
-	{ (Fl_Widget *)btnNotch,    214, 125,  50 },
-	{ (Fl_Widget *)sldrNOTCH,   266, 125, 156 },
-	{ (Fl_Widget *)sldrMICGAIN,  54, 145, 156 },
-	{ (Fl_Widget *)sldrPOWER,   266, 145, 156 },
+	{ (Fl_Widget *)btnVol,        2, 125,  50 }, // 0
+	{ (Fl_Widget *)sldrVOLUME,   54, 125, 368 }, // 1
+	{ (Fl_Widget *)sldrRFGAIN,   54, 145, 156 }, // 2
+	{ (Fl_Widget *)sldrSQUELCH, 266, 145, 156 }, // 3
+
+	{ (Fl_Widget *)sldrMICGAIN,  54, 165, 156 }, // 4
+	{ (Fl_Widget *)btnNotch,    214, 165,  50 }, // 5
+	{ (Fl_Widget *)sldrNOTCH,   266, 165, 156 }, // 6
+
+	{ (Fl_Widget *)btnNR,         2, 185,  50 }, // 7
+	{ (Fl_Widget *)sldrNR,       54, 185, 156 }, // 8
+	{ (Fl_Widget *)btnIFsh,     214, 185,  50 }, // 9
+	{ (Fl_Widget *)sldrIFSHIFT, 266, 185, 156 }, // 10
+
+	{ (Fl_Widget *)sldrPOWER,    54, 205, 368 }, // 11
+
 	{ (Fl_Widget *)NULL,          0,   0,   0 }
 };
 
@@ -101,14 +117,24 @@ void RIG_FT2000::initialize()
 	bandwidths_ = FT2000_SSBwidths;
 	bw_vals_ = FT2000_wvals_SSBwidths;
 
+	VECTOR (FT2000_att_labels, vFT2000_att_labels);
+	VECTOR (FT2000_pre_labels, vFT2000_pre_labels);
+
+	att_labels_ = FT2000_att_labels;
+	pre_labels_ = FT2000_pre_labels;
+
 	rig_widgets[0].W = btnVol;
 	rig_widgets[1].W = sldrVOLUME;
-	rig_widgets[2].W = btnIFsh;
-	rig_widgets[3].W = sldrIFSHIFT;
-	rig_widgets[4].W = btnNotch;
-	rig_widgets[5].W = sldrNOTCH;
-	rig_widgets[6].W = sldrMICGAIN;
-	rig_widgets[7].W = sldrPOWER;
+	rig_widgets[2].W = sldrRFGAIN;
+	rig_widgets[3].W = sldrSQUELCH;
+	rig_widgets[4].W = sldrMICGAIN;
+	rig_widgets[5].W = btnNotch;
+	rig_widgets[6].W = sldrNOTCH;
+	rig_widgets[7].W = btnNR;
+	rig_widgets[8].W = sldrNR;
+	rig_widgets[9].W = btnIFsh;
+	rig_widgets[10].W = sldrIFSHIFT;
+	rig_widgets[11].W = sldrPOWER;
 }
 
 RIG_FT2000::RIG_FT2000() {
@@ -149,6 +175,8 @@ RIG_FT2000::RIG_FT2000() {
 	has_mode_control =
 	has_noise_control =
 	has_bandwidth_control =
+	has_rf_control =
+	has_sql_control =
 	has_micgain_control =
 	has_notch_control =
 	has_attenuator_control =
@@ -291,7 +319,10 @@ void RIG_FT2000::set_vfoB (unsigned long long freq)
 
 int RIG_FT2000::get_smeter()
 {
-	cmd = "SM0;";
+	if (inuse == onB)
+		cmd = "SM1;";
+	else
+		cmd = "SM0;";
 	int ret = wait_char(';', 7, 100, "get smeter", ASC);
 
 	rig_trace(2, "get_smeter()", replystr.c_str());
@@ -301,7 +332,7 @@ int RIG_FT2000::get_smeter()
 	if (p == std::string::npos) return 0;
 	replystr[p + 6] = 0;
 	int mtr = atoi(&replystr[p + 3]);
-	mtr = mtr * 100.0 / 256.0;
+	mtr = mtr * 100.0 / 255.0;
 	return mtr;
 }
 
@@ -348,9 +379,22 @@ double RIG_FT2000::get_power_control()
 	if (p == std::string::npos) return 0;
 	replystr[p + 5] = 0;
 	int mtr = atoi(&replystr[p + 2]);
+	mtr = (int)(100.0 * mtr / 255.0);
 	return mtr;
 }
 
+// Transceiver power level
+void RIG_FT2000::set_power_control(double val)
+{
+	int ival = (int)(val * 255 / 100);
+	cmd = "PC000;";
+	for (int i = 4; i > 1; i--) {
+		cmd[i] += ival % 10;
+		ival /= 10;
+	}
+	sendCommand(cmd, 0);
+}
+
 // Volume control return 0 ... 100
 int RIG_FT2000::get_volume_control()
 {
@@ -378,18 +422,6 @@ void RIG_FT2000::set_volume_control(int val)
 	sendCommand(cmd, 0);
 }
 
-// Transceiver power level
-void RIG_FT2000::set_power_control(double val)
-{
-	int ival = (int)val;
-	cmd = "PC000;";
-	for (int i = 4; i > 1; i--) {
-		cmd[i] += ival % 10;
-		ival /= 10;
-	}
-	sendCommand(cmd, 0);
-}
-
 // Tranceiver PTT on/off
 void RIG_FT2000::set_PTT_control(int val)
 {
@@ -447,7 +479,7 @@ int RIG_FT2000::get_tune()
 
 int RIG_FT2000::next_attenuator()
 {
-	switch(atten_level) {
+	switch(atten_state) {
 		case 0: return 1;
 		case 1: return 2;
 		case 2: return 3;
@@ -458,7 +490,7 @@ int RIG_FT2000::next_attenuator()
 
 void RIG_FT2000::set_attenuator(int val)
 {
-	atten_level = val;
+	atten_state = val;
 	switch (val) {
 		case 1 :
 			cmd = "RA01;";
@@ -488,30 +520,30 @@ int RIG_FT2000::get_attenuator()
 	}
 	size_t p = replystr.rfind("RA");
 	if (p == std::string::npos) {
-		atten_level = 0;
+		atten_state = 0;
 		return 0;
 	}
 	int reply = replystr[p + 3];
 	switch (reply) {
 		case '1' :
-			atten_level = 1;
+			atten_state = 1;
 			break;
 		case '2' :
-			atten_level = 2;
+			atten_state = 2;
 			break;
 		case '3' :
-			atten_level = 3;
+			atten_state = 3;
 			break;
 		default :
-			atten_level = 0;
+			atten_state = 0;
 			break;
 	}
-	return atten_level;
+	return atten_state;
 }
 
 int RIG_FT2000::next_preamp()
 {
-	switch (preamp_level) {
+	switch (preamp_state) {
 		case 0: return 1;
 		case 1: return 2;
 		case 2: return 0;
@@ -521,8 +553,8 @@ int RIG_FT2000::next_preamp()
 
 void RIG_FT2000::set_preamp(int val)
 {
-	preamp_level = val;
-	switch (preamp_level) {
+	preamp_state = val;
+	switch (preamp_state) {
 		case 1 :
 			cmd = "PA01;";
 			break;
@@ -544,47 +576,27 @@ int RIG_FT2000::get_preamp()
 	rig_trace(2, "get_preamp()", replystr.c_str());
 
 	if (ret < 5) {
-		preamp_level = 0;
+		preamp_state = 0;
 		return 0;
 	}
 	size_t p = replystr.rfind("PA");
 	if (p == std::string::npos) {
-		preamp_level = 0;
+		preamp_state = 0;
 		return 0;
 	}
 	int reply = replystr[p + 3];
 	switch (reply) {
 		case '1' :
-			preamp_level = 1;
+			preamp_state = 1;
 			break;
 		case '2' :
-			preamp_level = 2;
+			preamp_state = 2;
 			break;
 		case '0' :
 		default :
-			preamp_level = 0;
+			preamp_state = 0;
 	}
-	return preamp_level;
-}
-
-const char *RIG_FT2000::ATT_label()
-{
-	if (atten_level == 1)
-		return "6 dB";
-	if (atten_level == 2)
-		return "12 dB";
-	if (atten_level == 3)
-		return "18 dB";
-	return "ATT";
-}
-
-const char *RIG_FT2000::PRE_label()
-{
-	if (preamp_level == 1)
-		return "Amp 1";
-	if (preamp_level == 2)
-		return "Amp 2";
-	return "PRE";
+	return preamp_state;
 }
 
 void RIG_FT2000::set_modeA(int val)
@@ -1034,3 +1046,130 @@ double RIG_FT2000::get_idd()
 	double mtr = atoi(&replystr[p+3]);
 	return mtr / 10.0;
 }
+
+void RIG_FT2000::set_squelch(int val)
+{
+	cmd = "SQ0000;";
+	if (inuse == onB) {
+		cmd[2] = '1';
+		progStatus.squelch_B = val;
+	} else
+		progStatus.squelch = progStatus.squelch_A = val;
+
+	for (int i = 5; i > 2; i--) {
+		cmd[i] = val % 10 + '0';
+		val /= 10;
+	}
+
+	set_trace(1, "set_squelch()");
+	sendCommand(cmd);
+	sett("");
+	showresp(WARN, ASC, "SET squelch", cmd, replystr);
+}
+
+int  RIG_FT2000::get_squelch()
+{
+	int sqval_A = 0;
+	cmd = rsp = "SQ0";
+	cmd += ';';
+	get_trace(1, "get_squelch() [A]");
+	wait_char(';', 7, 100, "get squelch", ASC);
+	gett("");
+
+	size_t p = replystr.rfind(rsp);
+	if (p == std::string::npos) {
+		if (inuse == onB)
+			return progStatus.squelch_B;
+		return progStatus.squelch_A;
+	}
+	for (int i = 3; i < 6; i++) {
+		sqval_A *= 10;
+		sqval_A += replystr[p+i] - '0';
+	}
+
+	int sqval_B = 0;
+	cmd = rsp = "SQ1";
+	cmd += ';';
+	get_trace(1, "get_squelch() [B]");
+	wait_char(';', 7, 100, "get squelch", ASC);
+	gett("");
+
+	p = replystr.rfind(rsp);
+	if (p == std::string::npos) {
+		if (inuse == onB)
+			return progStatus.squelch_B;
+		return progStatus.squelch_A;
+	}
+	for (int i = 3; i < 6; i++) {
+		sqval_B *= 10;
+		sqval_B += replystr[p+i] - '0';
+	}
+
+	progStatus.squelch_A = ceil(sqval_A);
+	progStatus.squelch_B = ceil(sqval_B);
+
+	if (inuse == onB)
+		return progStatus.squelch_B;
+
+	return progStatus.squelch_A;
+}
+
+void RIG_FT2000::set_rf_gain(int val)
+{
+	char szcmd[15];
+
+	if (inuse == onB) {
+		progStatus.rfgain_B = val;
+		snprintf(szcmd, sizeof(szcmd), "RG1%03d;", (100 - val) * 255 / 100);
+		cmd = szcmd;
+		set_trace(1, "set_rfgain A()");
+	} else {
+		progStatus.rfgain = progStatus.rfgain_A = val;
+		snprintf(szcmd, sizeof(szcmd), "RG0%03d;", (100 - val) * 255 / 100);
+		cmd = szcmd;
+		set_trace(1, "set_rfgain B()");
+	}
+
+	sendCommand(cmd);
+	sett("");
+	showresp(WARN, ASC, "SET rfgain A/B", cmd, replystr);
+}
+
+int  RIG_FT2000::get_rf_gain()
+{
+	if (inuse == onB) {
+		int RGval_B = 0;
+		cmd = rsp = "RG1";
+		cmd += ';';
+		get_trace(1, "get_rfgain() [B]");
+		wait_char(';', 7, 100, "get rfgain", ASC);
+		gett("");
+
+		size_t p = replystr.rfind(rsp);
+		if (p == std::string::npos) {
+			if (inuse == onB)
+				return progStatus.rfgain_B;
+			return progStatus.rfgain_A;
+		}
+		sscanf(replystr.c_str(), "RG1%d;", &RGval_B);
+		progStatus.rfgain_B = (255 - RGval_B) * 100 / 255;
+		return progStatus.rfgain_B;
+	}
+
+	int RGval_A = 0;
+	cmd = rsp = "RG0";
+	cmd += ';';
+	get_trace(1, "get_rfgain() [A]");
+	wait_char(';', 7, 100, "get rfgain", ASC);
+	gett("");
+
+	size_t p = replystr.rfind(rsp);
+	if (p == std::string::npos) {
+		if (inuse == onB)
+			return progStatus.rfgain_B;
+		return progStatus.rfgain_A;
+	}
+	sscanf(replystr.c_str(), "RG0%d;", &RGval_A);
+	progStatus.rfgain_A = (255 - RGval_A) * 100 / 255;
+	return progStatus.rfgain_A;
+}
