@@ -101,18 +101,31 @@ static const char *vUK_60m_label[] = {"VFO","U51","U52","U53","U54","U55","U56",
 static std::vector<std::string>& Channels_60m = US_60m_chan;
 static std::vector<std::string>& label_60m    = US_60m_label;
 
+//----------------------------------------------------------------------
+static std::vector<std::string>FT991_att_labels;
+static const char *vFT991_att_labels[] = { "ATT", "12 dB" };
+
+static std::vector<std::string>FT991_pre_labels;
+static const char *vFT991_pre_labels[] = { "IPO", "Amp 1", "Amp 2" };
+//----------------------------------------------------------------------
+
 static GUI rig_widgets[]= {
-	{ (Fl_Widget *)btnVol,        2, 125,  50 },
-	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 },
-	{ (Fl_Widget *)sldrRFGAIN,   54, 145, 156 },
-	{ (Fl_Widget *)btnIFsh,     214, 105,  50 },
-	{ (Fl_Widget *)sldrIFSHIFT, 266, 105, 156 },
-	{ (Fl_Widget *)btnNotch,    214, 125,  50 },
-	{ (Fl_Widget *)sldrNOTCH,   266, 125, 156 },
-	{ (Fl_Widget *)sldrMICGAIN, 266, 145, 156 },
-	{ (Fl_Widget *)sldrPOWER,   266, 165, 156 },
-	{ (Fl_Widget *)btnNR,         2, 165,  50 },
-	{ (Fl_Widget *)sldrNR,       54, 165, 156 },
+	{ (Fl_Widget *)btnVol,        2, 125,  50 }, // 0
+	{ (Fl_Widget *)sldrVOLUME,   54, 125, 368 }, // 1
+	{ (Fl_Widget *)sldrRFGAIN,   54, 145, 156 }, // 2
+	{ (Fl_Widget *)sldrSQUELCH, 266, 145, 156 }, // 3
+
+	{ (Fl_Widget *)sldrMICGAIN,  54, 165, 156 }, // 4
+	{ (Fl_Widget *)btnNotch,    214, 165,  50 }, // 5
+	{ (Fl_Widget *)sldrNOTCH,   266, 165, 156 }, // 6
+
+	{ (Fl_Widget *)btnNR,         2, 185,  50 }, // 7
+	{ (Fl_Widget *)sldrNR,       54, 185, 156 }, // 8
+	{ (Fl_Widget *)btnIFsh,     214, 185,  50 }, // 9
+	{ (Fl_Widget *)sldrIFSHIFT, 266, 185, 156 }, // 10
+
+	{ (Fl_Widget *)sldrPOWER,    54, 205, 368 }, // 11
+
 	{ (Fl_Widget *)NULL,          0,   0,   0 }
 };
 
@@ -183,6 +196,7 @@ RIG_FT991::RIG_FT991() {
 	has_power_control =
 	has_volume_control =
 	has_rf_control =
+	has_sql_control =
 	has_micgain_control =
 	has_mode_control =
 	has_noise_control =
@@ -198,8 +212,8 @@ RIG_FT991::RIG_FT991() {
 
 
 // derived specific
-	atten_level = 1;
-	preamp_level = 2;
+	atten_state = 1;
+	preamp_state = 2;
 	notch_on = false;
 	m_60m_indx = 0;
 
@@ -222,6 +236,12 @@ void RIG_FT991::initialize()
 	VECTOR (UK_60m_chan, vUK_60m_chan);
 	VECTOR (UK_60m_label, vUK_60m_label)
 
+	VECTOR (FT991_att_labels, vFT991_att_labels);
+	att_labels_ = FT991_att_labels;
+
+	VECTOR (FT991_pre_labels, vFT991_pre_labels);
+	pre_labels_ = FT991_pre_labels;
+
 	modes_ = FT991modes_;
 	bandwidths_ = FT991_widths_SSB;
 	bw_vals_ = FT991_wvals_SSB;
@@ -229,14 +249,15 @@ void RIG_FT991::initialize()
 	rig_widgets[0].W = btnVol;
 	rig_widgets[1].W = sldrVOLUME;
 	rig_widgets[2].W = sldrRFGAIN;
-	rig_widgets[3].W = btnIFsh;
-	rig_widgets[4].W = sldrIFSHIFT;
+	rig_widgets[3].W = sldrSQUELCH;
+	rig_widgets[4].W = sldrMICGAIN;
 	rig_widgets[5].W = btnNotch;
 	rig_widgets[6].W = sldrNOTCH;
-	rig_widgets[7].W = sldrMICGAIN;
-	rig_widgets[8].W = sldrPOWER;
-	rig_widgets[9].W = btnNR;
-	rig_widgets[10].W = sldrNR;
+	rig_widgets[7].W = btnNR;
+	rig_widgets[8].W = sldrNR;
+	rig_widgets[9].W = btnIFsh;
+	rig_widgets[10].W = sldrIFSHIFT;
+	rig_widgets[11].W = sldrPOWER;
 
 // set progStatus defaults
 	if (progStatus.notch_val < 10) progStatus.notch_val = 1500;
@@ -560,7 +581,7 @@ double RIG_FT991::get_idd()
 int RIG_FT991::get_power_out()
 {
 	cmd = rsp = "RM5";
-	sendCommand(cmd.append(";"));
+	cmd += ';';
 	wait_char(';',7, FL991_WAIT_TIME, "get pout", ASC);
 
 	size_t p = replystr.rfind(rsp);
@@ -675,7 +696,7 @@ int  RIG_FT991::get_tune()
 
 int  RIG_FT991::next_attenuator()
 {
-	switch (atten_level) {
+	switch (atten_state) {
 		case 0: return 1;
 		case 1: return 0;
 	}
@@ -684,9 +705,9 @@ int  RIG_FT991::next_attenuator()
 
 void RIG_FT991::set_attenuator(int val)
 {
-	atten_level = val;
+	atten_state = val;
 	cmd = "RA00;";
-	cmd[3] += atten_level;
+	cmd[3] += atten_state;
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET att", cmd, replystr);
 }
@@ -700,13 +721,13 @@ int RIG_FT991::get_attenuator()
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return progStatus.attenuator;
 	if (p + 3 >= replystr.length()) return progStatus.attenuator;
-	atten_level = replystr[p+3] - '0';
-	return atten_level;
+	atten_state = replystr[p+3] - '0';
+	return atten_state;
 }
 
 int  RIG_FT991::next_preamp()
 {
-	switch (preamp_level) {
+	switch (preamp_state) {
 		case 0: return 1;
 		case 1: return 2;
 		case 2: return 0;
@@ -716,9 +737,9 @@ int  RIG_FT991::next_preamp()
 
 void RIG_FT991::set_preamp(int val)
 {
-	preamp_level = val;
+	preamp_state = val;
 	cmd = "PA00;";
-	cmd[3] = '0' + preamp_level;
+	cmd[3] = '0' + preamp_state;
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET preamp", cmd, replystr);
 }
@@ -731,24 +752,8 @@ int RIG_FT991::get_preamp()
 
 	size_t p = replystr.rfind(rsp);
 	if (p != std::string::npos)
-		preamp_level = replystr[p+3] - '0';
-	return preamp_level;
-}
-
-const char *RIG_FT991::ATT_label()
-{
-	if (atten_level == 1)
-		return "12 dB";
-	return "ATT";
-}
-
-const char *RIG_FT991::PRE_label()
-{
-	if (preamp_level == 1)
-		return "Amp 1";
-	if (preamp_level == 2)
-		return "Amp 2";
-	return "IPO";
+		preamp_state = replystr[p+3] - '0';
+	return preamp_state;
 }
 
 int RIG_FT991::adjust_bandwidth(int val)
@@ -1409,16 +1414,16 @@ void RIG_FT991::set_xcvr_auto_on()
 // This command requires dummy data be initially sent. Then after one
 // second and before two seconds the command is sent.
 
-	cmd = "IF;"; // use as the dummy data
+	cmd = "PS1;"; // use as the dummy data
 	sendCommand(cmd);
 	update_progress(0);
-	for (int i = 0; i < 1500; i += 100) {
+	for (int i = 0; i < 1200; i += 100) {
 		MilliSleep(100);
 		update_progress(100 * i / 6000);
 		Fl::awake();
 	}
 
-	cmd = rsp = "PS";
+	cmd = rsp = "PS1";
 	cmd.append(";");
 	get_trace(1, "xcvr ON? ()");
 	wait_char(';',4, 500, "Test: Is Rig ON", ASC);
@@ -1563,3 +1568,35 @@ void RIG_FT991::sync_clock(char *tm)
 	sett("sync_time");
 }
 
+void RIG_FT991::set_squelch(int val)
+{
+	cmd = "SQ0000;";
+	for (int i = 5; i > 2; i--) {
+		cmd[i] = val % 10 + '0';
+		val /= 10;
+	}
+
+	set_trace(1, "set_squelch()");
+	sendCommand(cmd);
+	sett("");
+	showresp(WARN, ASC, "SET squelch", cmd, replystr);
+}
+
+int  RIG_FT991::get_squelch()
+{
+	int sqval = 0;
+	cmd = rsp = "SQ0";
+	cmd += ';';
+	get_trace(1, "get_squelch()");
+	wait_char(';',7, FL991_WAIT_TIME, "get squelch", ASC);
+	gett("");
+
+	size_t p = replystr.rfind(rsp);
+	if (p == std::string::npos) return progStatus.squelch;
+	for (int i = 3; i < 6; i++) {
+		sqval *= 10;
+		sqval += replystr[p+i] - '0';
+	}
+	return ceil(sqval);
+}
+
