@@ -57,7 +57,7 @@ static int FT991A_wvals_SSB[] = {
 
 static std::vector<std::string>FT991A_widths_SSBD;
 static const char *vFT991A_widths_SSBD[] = {
-   "50",  "100",  "150",  "200",  "250",  "300",  "350",  "400",  "450",  "500",
+	"50",  "100",  "150",  "200",  "250",  "300",  "350",  "400",  "450",  "500",
   "800", "1200", "1400", "1700", "2000", "2400", "3000" };
 
 static int FT991A_wvals_SSBD[] = {
@@ -66,7 +66,7 @@ static int FT991A_wvals_SSBD[] = {
 
 static std::vector<std::string>FT991A_widths_CW;
 static const char *vFT991A_widths_CW[] = {
-   "50",  "100",  "150",  "200",  "250",  "300",  "350",  "400",  "450",  "500",
+	"50",  "100",  "150",  "200",  "250",  "300",  "350",  "400",  "450",  "500",
   "800", "1200", "1400", "1700", "2000", "2400", "3000" };
 
 static int FT991A_wvals_CW[] = {
@@ -100,19 +100,31 @@ static const char *vUS_60m_label[] = {"VFO","U51","U52","U53","U54","U55","U56",
 //static std::vector<std::string>& Channels_60m = US_60m_chan;
 //static std::vector<std::string>& label_60m    = US_60m_label;
 
+//----------------------------------------------------------------------
+static std::vector<std::string>FT991A_att_labels;
+static const char *vFT991A_att_labels[] = { "ATT", "12 dB" };
+
+static std::vector<std::string>FT991A_pre_labels;
+static const char *vFT991A_pre_labels[] = { "IPO", "Amp 1", "Amp 2" };
+//----------------------------------------------------------------------
+
 static GUI rig_widgets[]= {
-	{ (Fl_Widget *)btnVol,        2, 125,  50 },
-	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 },
-	{ (Fl_Widget *)btnAGC,        2, 145,  50 },
-	{ (Fl_Widget *)sldrRFGAIN,   54, 145, 156 },
-	{ (Fl_Widget *)btnIFsh,     214, 105,  50 },
-	{ (Fl_Widget *)sldrIFSHIFT, 266, 105, 156 },
-	{ (Fl_Widget *)btnNotch,    214, 125,  50 },
-	{ (Fl_Widget *)sldrNOTCH,   266, 125, 156 },
-	{ (Fl_Widget *)sldrMICGAIN, 266, 145, 156 },
-	{ (Fl_Widget *)sldrPOWER,   266, 165, 156 },
-	{ (Fl_Widget *)btnNR,         2, 165,  50 },
-	{ (Fl_Widget *)sldrNR,       54, 165, 156 },
+	{ (Fl_Widget *)btnVol,        2, 125,  50 }, // 0
+	{ (Fl_Widget *)sldrVOLUME,   54, 125, 368 }, // 1
+	{ (Fl_Widget *)sldrRFGAIN,   54, 145, 156 }, // 2
+	{ (Fl_Widget *)sldrSQUELCH, 266, 145, 156 }, // 3
+
+	{ (Fl_Widget *)sldrMICGAIN,  54, 165, 156 }, // 4
+	{ (Fl_Widget *)btnNotch,    214, 165,  50 }, // 5
+	{ (Fl_Widget *)sldrNOTCH,   266, 165, 156 }, // 6
+
+	{ (Fl_Widget *)btnNR,         2, 185,  50 }, // 7
+	{ (Fl_Widget *)sldrNR,       54, 185, 156 }, // 8
+	{ (Fl_Widget *)btnIFsh,     214, 185,  50 }, // 9
+	{ (Fl_Widget *)sldrIFSHIFT, 266, 185, 156 }, // 10
+
+	{ (Fl_Widget *)sldrPOWER,    54, 205, 368 }, // 11
+
 	{ (Fl_Widget *)NULL,          0,   0,   0 }
 };
 
@@ -184,6 +196,7 @@ RIG_FT991A::RIG_FT991A() {
 	has_power_control =
 	has_volume_control =
 	has_rf_control =
+	has_sql_control =
 	has_micgain_control =
 	has_mode_control =
 	has_noise_control =
@@ -198,8 +211,8 @@ RIG_FT991A::RIG_FT991A() {
 	can_synch_clock = true;
 
 // derived specific
-	atten_level = 1;
-	preamp_level = 2;
+	atten_state = 1;
+	preamp_state = 2;
 	notch_on = false;
 	m_60m_indx = 0;
 
@@ -220,22 +233,28 @@ void RIG_FT991A::initialize()
 	VECTOR (US_60m_chan, vUS_60m_chan);
 	VECTOR (US_60m_label, vUS_60m_label);
 
+	VECTOR (FT991A_att_labels, vFT991A_att_labels);
+	att_labels_ = FT991A_att_labels;
+
+	VECTOR (FT991A_pre_labels, vFT991A_pre_labels);
+	pre_labels_ = FT991A_pre_labels;
+
 	modes_ = FT991Amodes_;
 	bandwidths_ = FT991A_widths_SSB;
 	bw_vals_ = FT991A_wvals_SSB;
 
 	rig_widgets[0].W = btnVol;
 	rig_widgets[1].W = sldrVOLUME;
-	rig_widgets[2].W = btnAGC;
-	rig_widgets[3].W = sldrRFGAIN;
-	rig_widgets[4].W = btnIFsh;
-	rig_widgets[5].W = sldrIFSHIFT;
-	rig_widgets[6].W = btnNotch;
-	rig_widgets[7].W = sldrNOTCH;
-	rig_widgets[8].W = sldrMICGAIN;
-	rig_widgets[9].W = sldrPOWER;
-	rig_widgets[10].W = btnNR;
-	rig_widgets[11].W = sldrNR;
+	rig_widgets[2].W = sldrRFGAIN;
+	rig_widgets[3].W = sldrSQUELCH;
+	rig_widgets[4].W = sldrMICGAIN;
+	rig_widgets[5].W = btnNotch;
+	rig_widgets[6].W = sldrNOTCH;
+	rig_widgets[7].W = btnNR;
+	rig_widgets[8].W = sldrNR;
+	rig_widgets[9].W = btnIFsh;
+	rig_widgets[10].W = sldrIFSHIFT;
+	rig_widgets[11].W = sldrPOWER;
 
 // set progStatus defaults
 	if (progStatus.notch_val < 10) progStatus.notch_val = 1500;
@@ -277,6 +296,23 @@ void RIG_FT991A::initialize()
 */
 }
 
+bool valid_reply (std::string str)
+{
+	if (str.empty()) {
+		get_trace (1, "no response");
+		return false;
+	}
+	if (str.find(";") == std::string::npos) {
+		get_trace (2, "missing semicolon", str.c_str());
+		return false;
+	}
+	if (str.find("?;") != std::string::npos) {
+		get_trace (2, "unknown command: ", str.c_str());
+		return false;
+	}
+	return true;
+}
+
 void RIG_FT991A::post_initialize()
 {
 //	enable_yaesu_bandselect(12, false);
@@ -288,6 +324,8 @@ bool RIG_FT991A::check ()
 	cmd = rsp = "FA";
 	cmd += ';';
 	int ret = wait_char(';',12, FL991A_WAIT_TIME, "check", ASC);
+	if ( !valid_reply( replystr ) )
+		return false;
 	if (ret >= 12) return true;
 	return false;
 }
@@ -299,9 +337,20 @@ unsigned long long RIG_FT991A::get_vfoA ()
 	wait_char(';',12, FL991A_WAIT_TIME, "get vfo A", ASC);
 	gett("get_vfoA");
 
+	if ( !valid_reply( replystr ) )
+		return freqA;
+
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return freqA;
-	p += 2;
+
+	replystr = replystr.substr(p);
+	if (replystr.length() < 12) {
+		char failed[50];
+		snprintf(failed, sizeof(failed), "get vfo A failed, returned %d bytes", (int)(replystr.length()));
+		get_trace(1, failed);
+		return freqA;
+	}
+	p = 2;
 	unsigned long long f = 0;
 	for (int n = 0; n < ndigits; n++)
 		f = f * 10 + replystr[p + n] - '0';
@@ -329,9 +378,20 @@ unsigned long long RIG_FT991A::get_vfoB ()
 	wait_char(';',12, FL991A_WAIT_TIME, "get vfo B", ASC);
 	gett("get_vfoB");
 
+	if ( !valid_reply( replystr ) )
+		return freqB;
+
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return freqB;
-	p += 2;
+
+	replystr = replystr.substr(p);
+	if (replystr.length() < 12) {
+		char failed[50];
+		snprintf(failed, sizeof(failed), "get vfo A failed, returned %d bytes", (int)(replystr.length()));
+		get_trace(1, failed);
+		return freqA;
+	}
+	p = 2;
 	unsigned long long f = 0;
 	for (int n = 0; n < ndigits; n++)
 		f = f * 10 + replystr[p + n] - '0';
@@ -438,6 +498,9 @@ int RIG_FT991A::get_split()
 	wait_char(';', 5, FL991A_WAIT_TIME, "get split tx vfo", ASC);
 	gett("get split tx");
 
+	if ( !valid_reply( replystr ) )
+		return false;
+
 	p = replystr.rfind(rsp);
 	if (p == std::string::npos) return false;
 	tx = replystr[p+3] - '0';
@@ -467,6 +530,9 @@ int RIG_FT991A::get_smeter()
 	wait_char(';',7, FL991A_WAIT_TIME, "get smeter", ASC);
 	gett("get_smeter");
 
+	if ( !valid_reply( replystr ) )
+		return 0;
+
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
@@ -494,6 +560,9 @@ int RIG_FT991A::get_swr()
 	wait_char(';',7, FL991A_WAIT_TIME, "get swr", ASC);
 	gett("get_swr");
 
+	if ( !valid_reply( replystr ) )
+		return 0;
+
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
@@ -508,6 +577,9 @@ int RIG_FT991A::get_alc()
 	wait_char(';',7, FL991A_WAIT_TIME, "get alc", ASC);
 	gett("get_alc");
 
+	if ( !valid_reply( replystr ) )
+		return 0;
+
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return 0;
 	if (p + 6 >= replystr.length()) return 0;
@@ -527,6 +599,9 @@ double RIG_FT991A::get_voltmeter()
 	wait_char(';',7, 100, "get vdd", ASC);
 	gett("get_voltmeter");
 
+	if ( !valid_reply( replystr ) )
+		return 0;
+
 	size_t p = replystr.rfind(resp);
 	if (p != std::string::npos) {
 		mtr = atoi(&replystr[p+3]);
@@ -544,6 +619,9 @@ double RIG_FT991A::get_idd()
 	wait_char(';',10, 100, "get alc", ASC);
 	gett("get_idd");
 
+	if ( !valid_reply( replystr ) )
+		return 0;
+
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return 0;
 	if (p + 9 >= replystr.length()) return 0;
@@ -555,13 +633,15 @@ double RIG_FT991A::get_idd()
 int RIG_FT991A::get_power_out()
 {
 	cmd = rsp = "RM5";
-	sendCommand(cmd.append(";"));
+	cmd += ';';
 	wait_char(';',7, FL991A_WAIT_TIME, "get pout", ASC);
 	gett("get_power_out");
 
+	if ( !valid_reply( replystr ) )
+		return 0;
+
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return 0;
-	if (p + 6 >= replystr.length()) return 0;
 	double mtr = (double)(atoi(&replystr[p+3]));
 
 	mtr = 3.8 - 0.0047 * mtr + .0022257 * mtr * mtr;
@@ -577,6 +657,9 @@ double RIG_FT991A::get_power_control()
 	wait_char(';',6, FL991A_WAIT_TIME, "get power", ASC);
 	gett("get_power_control");
 
+	if ( !valid_reply( replystr ) )
+		return progStatus.power_level;
+
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return progStatus.power_level;
 	if (p + 5 >= replystr.length()) return progStatus.power_level;
@@ -606,6 +689,9 @@ int RIG_FT991A::get_volume_control()
 	wait_char(';',7, FL991A_WAIT_TIME, "get vol", ASC);
 	gett("get_volume_control");
 
+	if ( !valid_reply( replystr ) )
+		return progStatus.volume;
+
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return progStatus.volume;
 	if (p + 6 >= replystr.length()) return progStatus.volume;
@@ -645,6 +731,9 @@ int RIG_FT991A::get_PTT()
 	wait_char(';', 4, FL991A_WAIT_TIME, "get PTT", ASC);
 	gett("get PTT");
 
+	if ( !valid_reply( replystr ) )
+		return ptt_;
+
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return ptt_;
 	switch (replystr[p+2]) {
@@ -672,6 +761,9 @@ int  RIG_FT991A::get_tune()
 	wait_char(';',6, FL991A_WAIT_TIME, "Tuner Enabled?", ASC);
 	gett("get_tune");
 
+	if ( !valid_reply( replystr ) )
+		return 0;
+
 	size_t p = replystr.rfind("AC");
 	if (p == std::string::npos) return 0;
 	if ((p + 5) >= replystr.length()) return 0;
@@ -683,7 +775,7 @@ int  RIG_FT991A::get_tune()
 
 int  RIG_FT991A::next_attenuator()
 {
-	switch (atten_level) {
+	switch (atten_state) {
 		case 0: return 1;
 		case 1: return 0;
 	}
@@ -692,9 +784,9 @@ int  RIG_FT991A::next_attenuator()
 
 void RIG_FT991A::set_attenuator(int val)
 {
-	atten_level = val;
+	atten_state = val;
 	cmd = "RA00;";
-	cmd[3] += atten_level;
+	cmd[3] += atten_state;
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET att", cmd, replystr);
 	sett("set_attenuator");
@@ -707,16 +799,19 @@ int RIG_FT991A::get_attenuator()
 	wait_char(';',5, FL991A_WAIT_TIME, "get att", ASC);
 	gett("get_attenuator");
 
+	if ( !valid_reply( replystr ) )
+		return progStatus.attenuator;
+
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return progStatus.attenuator;
 	if (p + 3 >= replystr.length()) return progStatus.attenuator;
-	atten_level = replystr[p+3] - '0';
-	return atten_level;
+	atten_state = replystr[p+3] - '0';
+	return atten_state;
 }
 
 int  RIG_FT991A::next_preamp()
 {
-	switch (preamp_level) {
+	switch (preamp_state) {
 		case 0: return 1;
 		case 1: return 2;
 		case 2: return 0;
@@ -726,9 +821,9 @@ int  RIG_FT991A::next_preamp()
 
 void RIG_FT991A::set_preamp(int val)
 {
-	preamp_level = val;
+	preamp_state = val;
 	cmd = "PA00;";
-	cmd[3] = '0' + preamp_level;
+	cmd[3] = '0' + preamp_state;
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET preamp", cmd, replystr);
 	sett("set_preamp");
@@ -741,26 +836,13 @@ int RIG_FT991A::get_preamp()
 	wait_char(';',5, FL991A_WAIT_TIME, "get pre", ASC);
 	gett("get_preamp");
 
+	if ( !valid_reply( replystr ) )
+		return preamp_state;
+
 	size_t p = replystr.rfind(rsp);
 	if (p != std::string::npos)
-		preamp_level = replystr[p+3] - '0';
-	return preamp_level;
-}
-
-const char *RIG_FT991A::ATT_label()
-{
-	if (atten_level == 1)
-		return "12 dB";
-	return "ATT";
-}
-
-const char *RIG_FT991A::PRE_label()
-{
-	if (preamp_level == 1)
-		return "Amp 1";
-	if (preamp_level == 2)
-		return "Amp 2";
-	return "IPO";
+		preamp_state = replystr[p+3] - '0';
+	return preamp_state;
 }
 
 int RIG_FT991A::adjust_bandwidth(int val)
@@ -851,6 +933,9 @@ int RIG_FT991A::get_modeA()
 	wait_char(';',5, FL991A_WAIT_TIME, "get mode A", ASC);
 	gett("get_modeA");
 
+	if ( !valid_reply( replystr ) )
+		return modeA;
+
 	size_t p = replystr.rfind(rsp);
 	if (p != std::string::npos) {
 		if (p + 3 < replystr.length()) {
@@ -894,6 +979,9 @@ int RIG_FT991A::get_modeB()
 	wait_char(';',28, FL991A_WAIT_TIME, "get mode B", ASC);
 	gett("get_modeB");
 
+	if ( !valid_reply( replystr ) )
+		return modeB;
+
 	size_t p = replystr.rfind(rsp);
 	if (p != std::string::npos) {
 		// JBA - n tells us where to start in the response
@@ -958,6 +1046,9 @@ int RIG_FT991A::get_bwA()
 	wait_char(';',6, FL991A_WAIT_TIME, "get bw A", ASC);
 	gett("get_bwA");
 
+	if ( !valid_reply( replystr ) )
+		return bwA;
+
 	p = replystr.rfind(rsp);
 	if (p == std::string::npos) return bwA;
 	if (p + 5 >= replystr.length()) return bwA;
@@ -1027,6 +1118,9 @@ int RIG_FT991A::get_bwB()
 	wait_char(';',6, FL991A_WAIT_TIME, "get bw B", ASC);
 	gett("get_bwB");
 
+	if ( !valid_reply( replystr ) )
+		return bwB;
+
 	p = replystr.rfind(rsp);
 	if (p == std::string::npos) return bwB;
 	if (p + 5 >= replystr.length()) return bwB;
@@ -1071,6 +1165,9 @@ bool RIG_FT991A::get_if_shift(int &val)
 	wait_char(';',9, FL991A_WAIT_TIME, "get if shift", ASC);
 	gett("get_if_shift");
 
+	if ( !valid_reply( replystr ) )
+		return progStatus.shift;
+
 	size_t p = replystr.rfind(rsp);
 	val = progStatus.shift_val;
 	if (p == std::string::npos) return progStatus.shift;
@@ -1122,6 +1219,9 @@ bool  RIG_FT991A::get_notch(int &val)
 	wait_char(';',8, FL991A_WAIT_TIME, "get notch on/off", ASC);
 	gett("get_notch");
 
+	if ( !valid_reply( replystr ) )
+		return progStatus.notch_val;
+
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return ison;
 
@@ -1160,6 +1260,10 @@ int  RIG_FT991A::get_auto_notch()
 	cmd = "BC0;";
 	wait_char(';',5, FL991A_WAIT_TIME, "get auto notch", ASC);
 	gett("get_auto_notch");
+
+	if ( !valid_reply( replystr ) )
+		return 0;
+
 	size_t p = replystr.rfind("BC0");
 	if (p == std::string::npos) return 0;
 	if (replystr[p+3] == '1') return 1;
@@ -1181,6 +1285,9 @@ int RIG_FT991A::get_noise()
 	wait_char(';',5, FL991A_WAIT_TIME, "get NB", ASC);
 	gett("get_noise");
 
+	if ( !valid_reply( replystr ) )
+		return 0;
+
 	size_t p = replystr.rfind("NB0");
 	if (p == std::string::npos) return 0;
 	return replystr[p+3] - '0';
@@ -1206,6 +1313,9 @@ int RIG_FT991A::get_mic_gain()
 	wait_char(';',6, FL991A_WAIT_TIME, "get mic", ASC);
 	gett("get_mic_gain");
 
+	if ( !valid_reply( replystr ) )
+		return progStatus.mic_gain;
+
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return progStatus.mic_gain;
 	int val = atoi(&replystr[p+2]);
@@ -1241,6 +1351,9 @@ int  RIG_FT991A::get_rf_gain()
 	wait_char(';',7, FL991A_WAIT_TIME, "get rfgain", ASC);
 	gett("get_rf_gain");
 
+	if ( !valid_reply( replystr ) )
+		return progStatus.rfgain;
+
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return progStatus.rfgain;
 	for (int i = 3; i < 6; i++) {
@@ -1283,6 +1396,9 @@ void RIG_FT991A::get_vox_gain()
 	wait_char(';', 6, FL991A_WAIT_TIME, "get VOX gain", ASC);
 	gett("get_vox_gain");
 
+	if ( !valid_reply( replystr ) )
+		return;
+
 	size_t p = replystr.rfind("VG");
 	if (p == std::string::npos) return;
 	replystr[p+5] = 0;
@@ -1313,6 +1429,9 @@ void RIG_FT991A::get_vox_hang()
 	wait_char(';', 7, FL991A_WAIT_TIME, "get VOX delay", ASC);
 	gett("get_vox_hang");
 
+	if ( !valid_reply( replystr ) )
+		return;
+
 	size_t p = replystr.rfind("VD");
 	if (p == std::string::npos) return;
 	replystr[p+6] = 0;
@@ -1410,6 +1529,10 @@ int  RIG_FT991A::get_noise_reduction_val()
 	cmd = rsp = "RL0";
 	cmd.append(";");
 	wait_char(';',6, FL991A_WAIT_TIME, "GET noise reduction val", ASC);
+
+	if ( !valid_reply( replystr ) )
+		return val;
+
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return val;
 	val = atoi(&replystr[p+3]);
@@ -1427,10 +1550,14 @@ void RIG_FT991A::set_noise_reduction(int val)
 
 int  RIG_FT991A::get_noise_reduction()
 {
-	int val;
+	int val = 0;
 	cmd = rsp = "NR0";
 	cmd.append(";");
 	wait_char(';',5, FL991A_WAIT_TIME, "GET noise reduction", ASC);
+
+	if ( !valid_reply( replystr ) )
+		return 0;
+
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return 0;
 	val = replystr[p+3] - '0';
@@ -1444,16 +1571,16 @@ void RIG_FT991A::set_xcvr_auto_on()
 // This command requires dummy data be initially sent. Then after one
 // second and before two seconds the command is sent.
 
-	cmd = "IF;"; // use as the dummy data
+	cmd = "PS1;"; // use as the dummy data
 	sendCommand(cmd);
 	update_progress(0);
-	for (int i = 0; i < 1500; i += 100) {
+	for (int i = 0; i < 1200; i += 100) {
 		MilliSleep(100);
 		update_progress(100 * i / 6000);
 		Fl::awake();
 	}
 
-	cmd = rsp = "PS";
+	cmd = rsp = "PS1";
 	cmd.append(";");
 	get_trace(1, "xcvr ON? ()");
 	wait_char(';',4, 500, "Test: Is Rig ON", ASC);
@@ -1530,6 +1657,9 @@ double RIG_FT991A::getVfoAdj()
 	sendCommand(cmd.append(";"));
 	wait_char(';',9, FL991A_WAIT_TIME, "get Vfo Adjust", ASC);
 
+	if ( !valid_reply( replystr ) )
+		return 0;
+
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return 0;
 	return (double)(atoi(&replystr[p+5]));
@@ -1548,6 +1678,10 @@ void RIG_FT991A::get_band_selection(int v)
 	cmd.assign("BS").append(bands[v-1]).append(";");
 	sendCommand(cmd);
 	sett("get band");
+
+	if ( !valid_reply( replystr ) )
+		return;
+
 }
 
 void RIG_FT991A::set_break_in()
@@ -1568,6 +1702,13 @@ int RIG_FT991A::get_break_in()
 {
 	cmd = "BI;";
 	wait_char(';', 4, FL991A_WAIT_TIME, "get break in", ASC);
+
+	if ( !valid_reply( replystr ) )
+		return progStatus.break_in;
+
+	if (replystr.find("BI") == std::string::npos)
+		return progStatus.break_in;
+
 	progStatus.break_in = (replystr[2] == '1');
 	if (progStatus.break_in) {
 		break_in_label("BK-IN");
@@ -1611,12 +1752,15 @@ void RIG_FT991A::sync_clock(char *tm)
 	sett("sync_time");
 }
 
-static int agcval = 0;
 int  RIG_FT991A::get_agc()
 {
 	cmd = "GT0;";
 	wait_char(';', 6, FL991A_WAIT_TIME, "get agc", ASC);
 	gett("get_agc");
+
+	if ( !valid_reply( replystr ) )
+		return agcval;
+
 	size_t p = replystr.rfind("GT");
 	if (p == std::string::npos) return agcval;
 
@@ -1658,3 +1802,39 @@ int  RIG_FT991A::agc_val()
 {
 	return (agcval);
 }
+
+void RIG_FT991A::set_squelch(int val)
+{
+	cmd = "SQ0000;";
+	for (int i = 5; i > 2; i--) {
+		cmd[i] = val % 10 + '0';
+		val /= 10;
+	}
+
+	set_trace(1, "set_squelch()");
+	sendCommand(cmd);
+	sett("");
+	showresp(WARN, ASC, "SET squelch", cmd, replystr);
+}
+
+int  RIG_FT991A::get_squelch()
+{
+	int sqval = 0;
+	cmd = rsp = "SQ0";
+	cmd += ';';
+	get_trace(1, "get_squelch()");
+	wait_char(';',7, FL991A_WAIT_TIME, "get squelch", ASC);
+	gett("");
+
+	if ( !valid_reply( replystr ) )
+		return sqval;
+
+	size_t p = replystr.rfind(rsp);
+	if (p == std::string::npos) return progStatus.squelch;
+	for (int i = 3; i < 6; i++) {
+		sqval *= 10;
+		sqval += replystr[p+i] - '0';
+	}
+	return ceil(sqval);
+}
+
