@@ -130,6 +130,17 @@ static const char *vFTdx101D_US_60m[] = {"", "126", "127", "128", "130"};
 
 static std::vector<std::string>& Channels_60m = FTdx101D_US_60m;
 
+//----------------------------------------------------------------------
+static std::vector<std::string>FTdx101D_att_labels;
+static const char *vFTdx101D_att_labels[] = { "ATT", "6 dB", "12 dB", "18 dB"};
+
+static std::vector<std::string>FTdx101D_pre_labels;
+static const char *vFTdx101D_pre_labels[] = { "IPO", "Amp 1", "Amp 2"};
+
+static std::vector<std::string>FTdx101D_nb_labels;
+static const char *vFTdx101D_nb_labels[] = { "NB", "NB on" };
+//----------------------------------------------------------------------
+
 static GUI rig_widgets[]= {
 	{ (Fl_Widget *)btnVol,        2, 125,  50 },
 	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 },
@@ -162,6 +173,15 @@ void RIG_FTdx101D::initialize()
 	bandwidths_ = FTdx101D_widths_SSB;
 	bw_vals_ = FTdx101D_wvals_SSB;
 
+	VECTOR (FTdx101D_att_labels, vFTdx101D_att_labels);
+	att_labels_ = FTdx101D_att_labels;
+
+	VECTOR (FTdx101D_pre_labels, vFTdx101D_pre_labels);
+	pre_labels_ = FTdx101D_pre_labels;
+
+	VECTOR (FTdx101D_nb_labels, vFTdx101D_nb_labels);
+	nb_labels_ = FTdx101D_nb_labels;
+
 	rig_widgets[0].W = btnVol;
 	rig_widgets[1].W = sldrVOLUME;
 	rig_widgets[2].W = sldrRFGAIN;
@@ -255,8 +275,8 @@ RIG_FTdx101D::RIG_FTdx101D() {
 	can_synch_clock = true;
 
 // derived specific
-	atten_level = 0;
-	preamp_level = 0;
+	atten_state = 0;
+	preamp_state = 0;
 	notch_on = false;
 	m_60m_indx = 0;
 
@@ -353,6 +373,26 @@ unsigned long long RIG_FTdx101D::get_vfoA ()
 	for (size_t n = 2; n < 11; n++)
 		f = f*10 + replystr[p+n] - '0';
 	freqA = f;
+
+	if (freqA >= 70000000 && freqA < 70500000) { // 70 cm band disable tuner
+		cmd = "AC;";
+		wait_char(';', 6, 100, "get tuner state", ASC);
+		if (replystr.length() >= 6) {
+			if (replystr[5] != '0') {
+				cmd = rsp = "MD0";
+				cmd += ';';
+				wait_char(';', 5, 100, "get mode A", ASC);
+				if (replystr[3] == 'E') {
+					sendCommand("MD01;");
+					sendCommand("AC000;");
+					sendCommand("MD0E;");
+				} else
+					sendCommand("AC000;");
+				MilliSleep(100);
+			}
+		}
+	}
+
 	return freqA;
 }
 
@@ -367,6 +407,16 @@ void RIG_FTdx101D::set_vfoA (unsigned long long freq)
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET vfo A", cmd, replystr);
 	sett("SET vfo A");
+	if (freq >= 70000000 && freq < 70500000) { // 70 cm band disable tuner
+		cmd = "AC;";
+		wait_char(';', 6, 100, "get tuner state", ASC);
+		if (replystr.length() >= 6) {
+			if (replystr[5] != '0') {
+				sendCommand("AC000;");
+				MilliSleep(100);
+			}
+		}
+	}
 }
 
 unsigned long long RIG_FTdx101D::get_vfoB ()
@@ -383,10 +433,29 @@ unsigned long long RIG_FTdx101D::get_vfoB ()
 	for (size_t n = 2; n < 11; n++)
 		f = f*10 + replystr[p+n] - '0';
 	freqB = f;
+
+	if (freqB >= 70000000 && freqB < 70500000) { // 70 cm band disable tuner
+		cmd = "AC;";
+		wait_char(';', 6, 100, "get tuner state", ASC);
+		if (replystr.length() >= 6) {
+			if (replystr[5] != '0') {
+				cmd = rsp = "MD1";
+				cmd += ';';
+				wait_char(';', 5, 100, "get mode B", ASC);
+				if (replystr[3] == 'E') {
+					sendCommand("MD11;");
+					sendCommand("AC000;");
+					sendCommand("MD1E;");
+				} else
+					sendCommand("AC000;");
+				MilliSleep(100);
+			}
+		}
+	}
+
 	return freqB;
 }
 
-
 void RIG_FTdx101D::set_vfoB (unsigned long long freq)
 {
 	freqB = freq;
@@ -398,9 +467,18 @@ void RIG_FTdx101D::set_vfoB (unsigned long long freq)
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET vfo B", cmd, replystr);
 	sett("SET vfo B");
+	if (freq >= 70000000 && freq < 70500000) { // 70 cm band disable tuner
+		cmd = "AC;";
+		wait_char(';', 6, 100, "get tuner state", ASC);
+		if (replystr.length() >= 6) {
+			if (replystr[5] != '0') {
+				sendCommand("AC000;");
+				MilliSleep(100);
+			}
+		}
+	}
 }
 
-
 bool RIG_FTdx101D::twovfos()
 {
 	return true;
@@ -504,11 +582,9 @@ int RIG_FTdx101D::get_swr()
 	return mtr / 2.56;
 }
 
-struct pwrpair {int mtr; float pwr;};
-
 int RIG_FTdx101D::get_power_out()
 {
-	static pwrpair pwrtbl[] = { 
+	static meterpair pwrtbl[] = { 
 		{  0,  0.0 },
 		{ 27,  5.0 },
 		{ 94, 25.0 },
@@ -528,13 +604,13 @@ int RIG_FTdx101D::get_power_out()
 	replystr.erase(3);
 	int mtr = atoi(replystr.c_str());
 	size_t i = 0;
-	for (i = 0; i < sizeof(pwrtbl) / sizeof(pwrpair) - 1; i++)
+	for (i = 0; i < sizeof(pwrtbl) / sizeof(meterpair) - 1; i++)
 		if (mtr >= pwrtbl[i].mtr && mtr < pwrtbl[i+1].mtr)
 			break;
 	if (mtr < 0) mtr = 0;
 	if (mtr > 205) mtr = 205;
-	int pwr = (int)ceil(pwrtbl[i].pwr + 
-			  (pwrtbl[i+1].pwr - pwrtbl[i].pwr)*(mtr - pwrtbl[i].mtr) / (pwrtbl[i+1].mtr - pwrtbl[i].mtr));
+	int pwr = (int)ceil(pwrtbl[i].val + 
+			  (pwrtbl[i+1].val - pwrtbl[i].val)*(mtr - pwrtbl[i].mtr) / (pwrtbl[i+1].mtr - pwrtbl[i].mtr));
 
 	if (pwr > 100) pwr = 100;
 
@@ -674,7 +750,7 @@ int RIG_FTdx101D::get_tune()
 
 int  RIG_FTdx101D::next_attenuator()
 {
-	switch (atten_level) {
+	switch (atten_state) {
 		case 0: return 1;
 		case 1: return 2;
 		case 2: return 3;
@@ -685,9 +761,9 @@ int  RIG_FTdx101D::next_attenuator()
 
 void RIG_FTdx101D::set_attenuator(int val)
 {
-	atten_level = val;
+	atten_state = val;
 	cmd = "RA00;";
-	cmd[3] += atten_level;
+	cmd[3] += atten_state;
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET att", cmd, replystr);
 }
@@ -703,13 +779,13 @@ int RIG_FTdx101D::get_attenuator()
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return progStatus.attenuator;
 	if (p + 3 >= replystr.length()) return progStatus.attenuator;
-	atten_level = replystr[p+3] - '0';
-	return atten_level;
+	atten_state = replystr[p+3] - '0';
+	return atten_state;
 }
 
 int  RIG_FTdx101D::next_preamp()
 {
-	switch (preamp_level) {
+	switch (preamp_state) {
 		case 0: return 1;
 		case 1: return 2;
 		case 2: return 0;
@@ -719,9 +795,9 @@ int  RIG_FTdx101D::next_preamp()
 
 void RIG_FTdx101D::set_preamp(int val)
 {
-	preamp_level = val;
+	preamp_state = val;
 	cmd = "PA00;";
-	cmd[3] = '0' + preamp_level;
+	cmd[3] = '0' + preamp_state;
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET preamp", cmd, replystr);
 }
@@ -736,28 +812,8 @@ int RIG_FTdx101D::get_preamp()
 
 	size_t p = replystr.rfind(rsp);
 	if (p != std::string::npos)
-		preamp_level = replystr[p+3] - '0';
-	return preamp_level;
-}
-
-const char *RIG_FTdx101D::ATT_label()
-{
-	if (atten_level == 1)
-		return "6 dB";
-	if (atten_level == 2)
-		return "12 dB";
-	if (atten_level == 3)
-		return "18 dB";
-	return "ATT";
-}
-
-const char *RIG_FTdx101D::PRE_label()
-{
-	if (preamp_level == 1)
-		return "Amp 1";
-	if (preamp_level == 2)
-		return "Amp 2";
-	return "IPO";
+		preamp_state = replystr[p+3] - '0';
+	return preamp_state;
 }
 
 static bool narrow = 0; // 0 - wide, 1 - narrow
@@ -1210,8 +1266,6 @@ int  RIG_FTdx101D::get_auto_notch()
 	return 0;
 }
 
-int FTdx101D_blanker_level = 0;
-
 void RIG_FTdx101D::set_noise(bool b)
 {
 	if (inuse == onB)
@@ -1219,11 +1273,12 @@ void RIG_FTdx101D::set_noise(bool b)
 	else
 		cmd = "NB00;";
 
+	nb_state = b;
 	if (b) {
 		cmd[3] = '1';
-		nb_label("NB on", true);
+		noise_blanker_label(nb_label(), true);
 	} else
-		nb_label("NB", false);
+		noise_blanker_label(nb_label(), false);
 
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET NB", cmd, replystr);
@@ -1241,16 +1296,16 @@ int RIG_FTdx101D::get_noise()
 	gett("get_noise()");
 
 	size_t p = replystr.rfind(rsp);
-	if (p == std::string::npos) return FTdx101D_blanker_level;
+	if (p == std::string::npos) return nb_state;
 
-	FTdx101D_blanker_level = replystr[p+3] - '0';
+	nb_state = replystr[p+3] - '0';
 
-	if (FTdx101D_blanker_level) {
-		nb_label("NB on", true);
+	if (nb_state) {
+		noise_blanker_label(nb_label(), true);
 	} else
-		nb_label("NB", false);
+		noise_blanker_label(nb_label(), false);
 
-	return FTdx101D_blanker_level;
+	return nb_state;
 }
 
 // val 0 .. 100
@@ -1520,7 +1575,7 @@ RIG_FTdx101MP::RIG_FTdx101MP() {
 
 int RIG_FTdx101MP::get_power_out()
 {
-	static pwrpair pwrtbl[] = { 
+	static meterpair pwrtbl[] = { 
 		{ 32, 10.0 },
 		{ 53, 20.0 },
 		{ 80, 40.0 },
@@ -1545,13 +1600,13 @@ int RIG_FTdx101MP::get_power_out()
 	replystr.erase(3);
 	int mtr = atoi(replystr.c_str());
 	size_t i = 0;
-	for (i = 0; i < sizeof(pwrtbl) / sizeof(pwrpair) - 1; i++)
+	for (i = 0; i < sizeof(pwrtbl) / sizeof(meterpair) - 1; i++)
 		if (mtr >= pwrtbl[i].mtr && mtr < pwrtbl[i+1].mtr)
 			break;
 	if (mtr < 0) mtr = 0;
 	if (mtr > 197) mtr = 197;
-	int pwr = (int)ceil(pwrtbl[i].pwr + 
-			  (pwrtbl[i+1].pwr - pwrtbl[i].pwr)*(mtr - pwrtbl[i].mtr) / (pwrtbl[i+1].mtr - pwrtbl[i].mtr));
+	int pwr = (int)ceil(pwrtbl[i].val + 
+			  (pwrtbl[i+1].val - pwrtbl[i].val)*(mtr - pwrtbl[i].mtr) / (pwrtbl[i+1].mtr - pwrtbl[i].mtr));
 
 	if (pwr > 200) pwr = 200;
 
