@@ -103,6 +103,17 @@ static const char *vUK_60m_label[] = {"VFO","U51","U52","U53","U54","U55","U56",
 static std::vector<std::string>& Channels_60m = US_60m_chan;
 static std::vector<std::string>& label_60m    = US_60m_label;
 
+//----------------------------------------------------------------------
+static std::vector<std::string>FTdx1200_att_labels;
+static const char *vFTdx1200_att_labels[] = { "ATT", "6 dB", "12 dB", "18 dB"};
+
+static std::vector<std::string>FTdx1200_pre_labels;
+static const char *vFTdx1200_pre_labels[] = { "IPO", "Amp 1", "Amp 2"};
+
+static std::vector<std::string>FTdx1200_nb_labels;
+static const char *vFTdx1200_nb_labels[] = { "NB", "NB 1", "NB 2" };
+//----------------------------------------------------------------------
+
 static GUI rig_widgets[]= {
 	{ (Fl_Widget *)btnVol,        2, 125,  50 },
 	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 },
@@ -195,8 +206,8 @@ RIG_FTdx1200::RIG_FTdx1200() {
 	has_tune_control = true;
 
 // derived specific
-	atten_level = 3;
-	preamp_level = 2;
+	atten_state = 3;
+	preamp_state = 2;
 	notch_on = false;
 	m_60m_indx = 0;
 
@@ -222,6 +233,15 @@ void RIG_FTdx1200::initialize()
 	bandwidths_ = FTdx1200_widths_SSB;
 	bw_vals_ = FTdx1200_wvals_SSB;
 
+	VECTOR (FTdx1200_att_labels, vFTdx1200_att_labels);
+	att_labels_ = FTdx1200_att_labels;
+
+	VECTOR (FTdx1200_pre_labels, vFTdx1200_pre_labels);
+	pre_labels_ = FTdx1200_pre_labels;
+
+	VECTOR (FTdx1200_nb_labels, vFTdx1200_nb_labels);
+	nb_labels_ = FTdx1200_nb_labels;
+
 	rig_widgets[0].W = btnVol;
 	rig_widgets[1].W = sldrVOLUME;
 	rig_widgets[2].W = sldrRFGAIN;
@@ -729,7 +749,7 @@ void RIG_FTdx1200::tune_rig(int)
 
 int  RIG_FTdx1200::next_attenuator()
 {
-	switch (atten_level) {
+	switch (atten_state) {
 		case 0: return 1;
 		case 1: return 2;
 		case 2: return 3;
@@ -740,9 +760,9 @@ int  RIG_FTdx1200::next_attenuator()
 
 void RIG_FTdx1200::set_attenuator(int val)
 {
-	atten_level = val;
+	atten_state = val;
 	cmd = "RA00;";
-	cmd[3] += atten_level;
+	cmd[3] += atten_state;
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET att", cmd, replystr);
 	set_trace(3,"set_attenuator", cmd.c_str(), replystr.c_str());
@@ -759,13 +779,13 @@ int RIG_FTdx1200::get_attenuator()
 	size_t p = replystr.rfind(rsp);
 	if (p == std::string::npos) return progStatus.attenuator;
 	if (p + 3 >= replystr.length()) return progStatus.attenuator;
-	atten_level = replystr[p+3] - '0';
-	return atten_level;
+	atten_state = replystr[p+3] - '0';
+	return atten_state;
 }
 
 int RIG_FTdx1200::next_preamp()
 {
-	switch (preamp_level) {
+	switch (preamp_state) {
 		case 0: return 1;
 		case 1: return 2;
 		case 2: return 0;
@@ -775,9 +795,9 @@ int RIG_FTdx1200::next_preamp()
 
 void RIG_FTdx1200::set_preamp(int val)
 {
-	preamp_level = val;
+	preamp_state = val;
 	cmd = "PA00;";
-	cmd[3] = '0' + preamp_level;
+	cmd[3] = '0' + preamp_state;
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET preamp", cmd, replystr);
 	set_trace(3,"set_preamp", cmd.c_str(), replystr.c_str());
@@ -793,28 +813,8 @@ int RIG_FTdx1200::get_preamp()
 
 	size_t p = replystr.rfind(rsp);
 	if (p != std::string::npos)
-		preamp_level = replystr[p+3] - '0';
-	return preamp_level;
-}
-
-const char *RIG_FTdx1200::ATT_label()
-{
-	if (atten_level == 1)
-		return "6 dB";
-	if (atten_level == 2)
-		return "12 dB";
-	if (atten_level == 3)
-		return "18 dB";
-	return "ATT";
-}
-
-const char *RIG_FTdx1200::PRE_label()
-{
-	if (preamp_level == 1)
-		return "Amp 1";
-	if (preamp_level == 2)
-		return "Amp 2";
-	return "IPO";
+		preamp_state = replystr[p+3] - '0';
+	return preamp_state;
 }
 
 int RIG_FTdx1200::adjust_bandwidth(int val)
@@ -1242,22 +1242,20 @@ int  RIG_FTdx1200::get_auto_notch()
 	return 0;
 }
 
-int FTdx1200_blanker_level = 2;
-
 void RIG_FTdx1200::set_noise(bool b)
 {
 	cmd = "NB00;";
-	if (FTdx1200_blanker_level == 0) {
-		FTdx1200_blanker_level = 1;
-		nb_label("NB 1", true);
-	} else if (FTdx1200_blanker_level == 1) {
-		FTdx1200_blanker_level = 2;
-		nb_label("NB 2", true);
-	} else if (FTdx1200_blanker_level == 2) {
-		FTdx1200_blanker_level = 0;
-		nb_label("NB", false);
+	if (nb_state == 0) {
+		nb_state = 1;
+		noise_blanker_label(nb_label(), true);
+	} else if (nb_state == 1) {
+		nb_state = 2;
+		noise_blanker_label(nb_label(), true);
+	} else if (nb_state == 2) {
+		nb_state = 0;
+		noise_blanker_label(nb_label(), false);
 	}
-	cmd[3] = '0' + FTdx1200_blanker_level;
+	cmd[3] = '0' + nb_state;
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET NB", cmd, replystr);
 	set_trace(3,"set_noise", cmd.c_str(), replystr.c_str());
@@ -1272,18 +1270,18 @@ int RIG_FTdx1200::get_noise()
 	get_trace(3, "get_noise()", cmd.c_str(), replystr.c_str());
 
 	size_t p = replystr.rfind(rsp);
-	if (p == std::string::npos) return FTdx1200_blanker_level;
+	if (p == std::string::npos) return nb_state;
 
-	FTdx1200_blanker_level = replystr[p+3] - '0';
-	if (FTdx1200_blanker_level == 1) {
-		nb_label("NB 1", true);
-	} else if (FTdx1200_blanker_level == 2) {
-		nb_label("NB 2", true);
+	nb_state = replystr[p+3] - '0';
+	if (nb_state == 1) {
+		noise_blanker_label(nb_label(), true);
+	} else if (nb_state == 2) {
+		noise_blanker_label(nb_label(), true);
 	} else {
-		nb_label("NB", false);
-		FTdx1200_blanker_level = 0;
+		noise_blanker_label(nb_label(), false);
+		nb_state = 0;
 	}
-	return FTdx1200_blanker_level;
+	return nb_state;
 }
 
 // val 0 .. 100
